@@ -173,7 +173,7 @@ public:
     bool permission;
 };
 
-Q_DECLARE_TYPEINFO(URLActionRule, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(URLActionRule, Q_RELOCATABLE_TYPE);
 
 class KAuthorizedPrivate
 {
@@ -191,7 +191,7 @@ public:
             blockEverything = true;
             return;
         }
-        actionRestrictions = config->hasGroup("KDE Action Restrictions") && !kde_kiosk_exception;
+        actionRestrictions = config->hasGroup(QStringLiteral("KDE Action Restrictions")) && !kde_kiosk_exception;
     }
 
     ~KAuthorizedPrivate()
@@ -205,12 +205,17 @@ public:
 };
 
 Q_GLOBAL_STATIC(KAuthorizedPrivate, authPrivate)
-#define MY_D KAuthorizedPrivate *d = authPrivate();
+#define KAUTHORIZED_D KAuthorizedPrivate *d = authPrivate()
+
+KAuthorized::KAuthorized()
+    : QObject(nullptr)
+{
+}
 
 bool KAuthorized::authorize(const QString &genericAction)
 {
-    MY_D if (d->blockEverything)
-    {
+    KAUTHORIZED_D;
+    if (d->blockEverything) {
         return false;
     }
 
@@ -218,7 +223,7 @@ bool KAuthorized::authorize(const QString &genericAction)
         return true;
     }
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE Action Restrictions");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KDE Action Restrictions"));
     return cg.readEntry(genericAction, true);
 }
 
@@ -235,8 +240,8 @@ bool KAuthorized::authorize(KAuthorized::GenericRestriction action)
 
 bool KAuthorized::authorizeAction(const QString &action)
 {
-    MY_D if (d->blockEverything)
-    {
+    KAUTHORIZED_D;
+    if (d->blockEverything) {
         return false;
     }
     if (!d->actionRestrictions || action.isEmpty()) {
@@ -256,38 +261,20 @@ bool KAuthorized::authorizeAction(KAuthorized::GenericAction action)
     return false;
 }
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 24)
-bool KAuthorized::authorizeKAction(const QString &action)
-{
-    return authorizeAction(action);
-}
-#endif
-
 bool KAuthorized::authorizeControlModule(const QString &menuId)
 {
     if (menuId.isEmpty() || kde_kiosk_exception) {
         return true;
     }
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE Control Module Restrictions");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KDE Control Module Restrictions"));
     return cg.readEntry(menuId, true);
 }
 
-QStringList KAuthorized::authorizeControlModules(const QStringList &menuIds)
-{
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE Control Module Restrictions");
-    QStringList result;
-    for (const auto &id : menuIds) {
-        if (cg.readEntry(id, true)) {
-            result.append(id);
-        }
-    }
-    return result;
-}
-
 // Exported for unittests (e.g. in KIO, we're missing tests for this in kconfig)
 KCONFIGCORE_EXPORT void loadUrlActionRestrictions(const KConfigGroup &cg)
 {
-    MY_D const QString Any;
+    KAUTHORIZED_D;
+    const QString Any;
 
     d->urlActionRestrictions.clear();
     d->urlActionRestrictions.append(URLActionRule("open", Any, Any, Any, Any, Any, Any, true));
@@ -358,15 +345,16 @@ KCONFIGCORE_EXPORT void loadUrlActionRestrictions(const KConfigGroup &cg)
     }
 }
 
-namespace KAuthorized
+namespace KAuthorizedInternal
 {
 /**
  * Helper for KAuthorized::allowUrlAction in KIO
  * @private
  */
-KCONFIGCORE_EXPORT void allowUrlActionInternal(const QString &action, const QUrl &_baseURL, const QUrl &_destURL)
+KCONFIGCORE_EXPORT void allowUrlAction(const QString &action, const QUrl &_baseURL, const QUrl &_destURL)
 {
-    MY_D QMutexLocker locker((&d->mutex));
+    KAUTHORIZED_D;
+    QMutexLocker locker((&d->mutex));
 
     const QString basePath = _baseURL.adjusted(QUrl::StripTrailingSlash).path();
     const QString destPath = _destURL.adjusted(QUrl::StripTrailingSlash).path();
@@ -380,9 +368,10 @@ KCONFIGCORE_EXPORT void allowUrlActionInternal(const QString &action, const QUrl
  * @private
  */
 KCONFIGCORE_EXPORT bool
-authorizeUrlActionInternal(const QString &action, const QUrl &_baseURL, const QUrl &_destURL, const QString &baseClass, const QString &destClass)
+authorizeUrlAction(const QString &action, const QUrl &_baseURL, const QUrl &_destURL, const QString &baseClass, const QString &destClass)
 {
-    MY_D QMutexLocker locker(&(d->mutex));
+    KAUTHORIZED_D;
+    QMutexLocker locker(&(d->mutex));
     if (d->blockEverything) {
         return false;
     }
@@ -393,7 +382,7 @@ authorizeUrlActionInternal(const QString &action, const QUrl &_baseURL, const QU
 
     bool result = false;
     if (d->urlActionRestrictions.isEmpty()) {
-        KConfigGroup cg(KSharedConfig::openConfig(), "KDE URL Restrictions");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KDE URL Restrictions"));
         loadUrlActionRestrictions(cg);
     }
 
@@ -412,7 +401,6 @@ authorizeUrlActionInternal(const QString &action, const QUrl &_baseURL, const QU
     }
     return result;
 }
-
 } // namespace
 
 #include "moc_kauthorized.cpp"
